@@ -1,3 +1,3 @@
 from __future__ import absolute_import
 
-name = "article_extractor"
+name = "extractor"
